@@ -1,5 +1,6 @@
 from .components import Component
-from .element import Element
 from .html import *
-from .styling import Style
 from .rendering.html import render
+from .core import JS
+
+__version__ = "0.8.3"
